@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::PluginBundle::Author::GETTY::AUTHORITY = 'cpan:GETTY';
 }
 # ABSTRACT: BeLike::GETTY when you build your dists
-$Dist::Zilla::PluginBundle::Author::GETTY::VERSION = '0.108';
+$Dist::Zilla::PluginBundle::Author::GETTY::VERSION = '0.109';
 use Moose;
 use Moose::Autobox;
 use Dist::Zilla;
@@ -384,7 +384,7 @@ Dist::Zilla::PluginBundle::Author::GETTY - BeLike::GETTY when you build your dis
 
 =head1 VERSION
 
-version 0.108
+version 0.109
 
 =head1 SYNOPSIS
 
@@ -414,7 +414,7 @@ are default):
   no_changes = 0
   no_changelog_from_git = 0
   no_podweaver = 0
-  module_build_tiny = 0
+  xs = 0
   installrelease_command = cpanm .
 
 In default configuration it is equivalent to:
@@ -546,6 +546,11 @@ L<Dist::Zilla::Plugin::NextRelease> will be used.
 
 If set to 1, then L<Dist::Zilla::Plugin::PodWeaver> is not used.
 
+=head2 xs
+
+If set to 1, then L<Dist::Zilla::Plugin::ModuleBuildTiny>. This will also
+automatically set B<no_makemaker> to 1.
+
 =head2 no_install
 
 If set to 1, the resulting distribution can't be installed.
